Enum RecordInstruction

pub enum RecordInstruction<'a> {
    Initialize,
    Write {
        offset: u64,
        data: &'a [u8],
    },
    SetAuthority,
    CloseAccount,
    Reallocate {
        data_length: u64,
    },
}
Instructions supported by the program

Variants



Initialize

Create a new record

Accounts expected by this instruction:

  1. [writable] Record account, must be uninitialized
  2. [] Record authority


Write

Write to the provided record account

Accounts expected by this instruction:

  1. [writable] Record account, must be previously initialized
  2. [signer] Current record authority

Fields

offset: u64

Offset to start writing record, expressed as u64.

data: &'a [u8]

Data to replace the existing record data



SetAuthority

Update the authority of the provided record account

Accounts expected by this instruction:

  1. [writable] Record account, must be previously initialized
  2. [signer] Current record authority
  3. [] New record authority


CloseAccount

Close the provided record account, draining lamports to recipient account

Accounts expected by this instruction:

  1. [writable] Record account, must be previously initialized
  2. [signer] Record authority
  3. [] Receiver of account lamports


Reallocate

Reallocate additional space in a record account

If the record account already has enough space to hold the specified data length, then the instruction does nothing.

Accounts expected by this instruction:

  1. [writable] The record account to reallocate
  2. [signer] The account’s owner

Fields

data_length: u64

The length of the data to hold in the record account excluding meta data

Implementations

Source

impl<'a> RecordInstruction<'a>

pub fn unpack(input: &'a [u8]) -> Result<Self, ProgramError>

Unpacks a byte buffer into a RecordInstruction.

pub fn pack(&self) -> Vec<u8>

Packs a RecordInstruction into a byte buffer.