pub enum RecordInstruction<'a> {
Initialize,
Write {
offset: u64,
data: &'a [u8],
},
SetAuthority,
CloseAccount,
Reallocate {
data_length: u64,
},
}Expand description
Instructions supported by the program
Variants
Initialize
Create a new record
Accounts expected by this instruction:
[writable]Record account, must be uninitialized[]Record authority
Write
Write to the provided record account
Accounts expected by this instruction:
[writable]Record account, must be previously initialized[signer]Current record authority
Fields
SetAuthority
Update the authority of the provided record account
Accounts expected by this instruction:
[writable]Record account, must be previously initialized[signer]Current record authority[]New record authority
CloseAccount
Close the provided record account, draining lamports to recipient account
Accounts expected by this instruction:
[writable]Record account, must be previously initialized[signer]Record authority[]Receiver of account lamports
Reallocate
Reallocate additional space in a record account
If the record account already has enough space to hold the specified data length, then the instruction does nothing.
Accounts expected by this instruction:
[writable]The record account to reallocate[signer]The account’s owner
Implementations
Sourceimpl<'a> RecordInstruction<'a>
impl<'a> RecordInstruction<'a>
Sourcepub fn unpack(input: &'a [u8]) -> Result<Self, ProgramError>
pub fn unpack(input: &'a [u8]) -> Result<Self, ProgramError>
Unpacks a byte buffer into a RecordInstruction.