Struct spl_record::state::RecordData
source · pub struct RecordData {
pub version: u8,
pub authority: Pubkey,
pub data: Data,
}Expand description
Struct wrapping data and providing metadata
Fields
version: u8Struct version, allows for upgrades to the program
The account allowed to update the data
data: DataThe data contained by the account, could be anything serializable
Implementations
sourceimpl RecordData
impl RecordData
sourcepub const CURRENT_VERSION: u8 = 1u8
pub const CURRENT_VERSION: u8 = 1u8
Version to fill in on new created accounts
sourcepub const WRITABLE_START_INDEX: usize = 33usize
pub const WRITABLE_START_INDEX: usize = 33usize
Start of writable account data, after version and authority